@@ -38,8 +38,8 @@ class ImageRecognition(object):
         self.classification_by_regression = classification_by_regression
 
         self.input_placeholder = tf.placeholder(tf.float32, shape=(None, self.input_height, self.input_width, self.input_channel))
+        self.output_placeholder = tf.placeholder(tf.float32, shape=(None, len(self.classes)))
         
-
         if self.classification_by_regression: 
             if json_label_file is None: 
                 print ("You have to provide a json file for regression value, format <filename>.jpg: regression_value, ...")
@@ -47,12 +47,7 @@ class ImageRecognition(object):
             else: 
                 f = open(json_label_file)
                 self.regression_value = json.load(f)
-
-            self.output_placeholder = tf.placeholder(tf.float32, shape=(None, 1))
-        
-        else: 
-            self.output_placeholder = tf.placeholder(tf.float32, shape=(None, len(self.classes)))
-
+           
 
     def build_resnetv2(self, 
                        input_tensor,
@@ -91,31 +86,21 @@ class ImageRecognition(object):
         
         with tf.variable_scope('resnet_v2_101'):
             depth = out.get_shape().as_list()[-1]
+            out = new_fc_layer(out, 
+                                num_inputs = depth, 
+                                num_outputs = len(self.classes), 
+                                name = 'fc1', 
+                                dropout_val= 1 - dropout_rate, 
+                                activation="NONE",
+                                lrelu_alpha=0.2, 
+                                data_type=tf.float32,
+                                is_training=is_training,
+                                use_bias=False)
 
             if self.classification_by_regression: 
-                out = new_fc_layer(out, 
-                                    num_inputs = depth, 
-                                    num_outputs = 1, 
-                                    name = 'fc1', 
-                                    dropout_val= 1 - dropout_rate, 
-                                    activation="NONE",
-                                    lrelu_alpha=0.2, 
-                                    data_type=tf.float32,
-                                    is_training=is_training,
-                                    use_bias=False)
                 out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-            else: 
-                out = new_fc_layer(out, 
-                                    num_inputs = depth, 
-                                    num_outputs = len(self.classes), 
-                                    name = 'fc1', 
-                                    dropout_val= 1 - dropout_rate, 
-                                    activation="NONE",
-                                    lrelu_alpha=0.2, 
-                                    data_type=tf.float32,
-                                    is_training=is_training,
-                                    use_bias=False)
 
+            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -183,32 +168,21 @@ class ImageRecognition(object):
             
             depth = out.get_shape().as_list()[-1]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
+            out = new_fc_layer(out, 
+                                num_inputs = depth, 
+                                num_outputs = len(self.classes), 
+                                name = 'fc1', 
+                                dropout_val=1, 
+                                activation="NONE",
+                                lrelu_alpha=0.2, 
+                                data_type=tf.float32,
+                                is_training=is_training,
+                                use_bias=False)
 
             if self.classification_by_regression:
-                out = new_fc_layer(out, 
-                                    num_inputs = depth, 
-                                    num_outputs = 1, 
-                                    name = 'fc1', 
-                                    dropout_val=1, 
-                                    activation="NONE",
-                                    lrelu_alpha=0.2, 
-                                    data_type=tf.float32,
-                                    is_training=is_training,
-                                    use_bias=False)
                 out = 6 /(1 + tf.exp(-0.2 * out)) - 3
             
             else: 
-                out = new_fc_layer(out, 
-                                    num_inputs = depth, 
-                                    num_outputs = len(self.classes), 
-                                    name = 'fc1', 
-                                    dropout_val=1, 
-                                    activation="NONE",
-                                    lrelu_alpha=0.2, 
-                                    data_type=tf.float32,
-                                    is_training=is_training,
-                                    use_bias=False)
-
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -260,25 +234,10 @@ class ImageRecognition(object):
                                         use_batchnorm=True) 
                 size = out.get_shape().as_list()[1]
             
-            print (out)
             depth =  out.get_shape().as_list()[1] *  out.get_shape().as_list()[2] * out.get_shape().as_list()[3]
             out = tf.reshape(out, [tf.shape(out)[0], -1])
 
-            if self.classification_by_regression:
-                out = new_fc_layer(out, 
-                                    num_inputs = depth, 
-                                    num_outputs = 1, 
-                                    name = 'fc1', 
-                                    dropout_val=1 - dropout_rate, 
-                                    activation="NONE",
-                                    lrelu_alpha=0.2, 
-                                    data_type=tf.float32,
-                                    is_training=is_training,
-                                    use_bias=False)
-                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
-
-            else: 
-                out = new_fc_layer(out, 
+            out = new_fc_layer(out, 
                                     num_inputs = depth, 
                                     num_outputs = len(self.classes), 
                                     name = 'fc1', 
@@ -289,6 +248,10 @@ class ImageRecognition(object):
                                     is_training=is_training,
                                     use_bias=False)
 
+            if self.classification_by_regression:
+                out = 6 /(1 + tf.exp(-0.2 * out)) - 3
+
+            else: 
                 if len(self.classes) == 1:
                     out = tf.nn.sigmoid(out)
                 else:
@@ -301,12 +264,12 @@ class ImageRecognition(object):
     def __prepare_output_val(self, index=None, key=None):
         if self.classification_by_regression: 
             if key in self.regression_value:
-                regression_val = [self.regression_value[key]]
+                regression_val = [1.0-self.regression_value[key], self.regression_value[key]]
                 return regression_val, False
 
             else: 
                 if index == self.classes[1]:
-                    regression_val = [1.0]
+                    regression_val = [0, 1.0]
                     return regression_val, False
 
                 else: 
